==> smartdev-iot-com-0.0.4.tgz: package/components/enum/IOTPoleSlider/grapesjsConfig.tsx <==
import React from 'react';
import { ComponentsType, iProperty, TagType } from '../../base/type';
import IOTPoleSlider from './IOTPoleSlider';
import { IOTPoleSliderProps } from './interface';
import iGrapesJSConfig from '../../type';
import { iIOTPoleSliderJSON } from '.';
import { mergeParameters } from '../../base/utils';
import { getEnumItems } from '../IOTCordEntryEnum/grapesjsConfig';

 const grapesJSConfig: iGrapesJSConfig<iIOTPoleSliderJSON, IOTPoleSliderProps> = {
   type: [ComponentsType.EnumType],
   id: 'IOTPoleSlider',
   tag: TagType.IOTPoleSlider,
   access: 'rw',
   render: (jsonData, ...args) => {
     const props = mergeParameters(jsonData, ...args);
     return <IOTPoleSlider {...props}></IOTPoleSlider>;
   },
   buildData: (mock: boolean = false, property?: iProperty) => {
     if (property === undefined) return;
     //区分类
     const props: iIOTPoleSliderJSON = {
       title: property['display-name'],
       icon: { value: 'insideicon-cu-1', show: true },
       streamId: property.streamName,
       type: property?.valuedef?.type,
       disabled: false,
       curValue:'',
      //  handler: function (val: any): void {
      //    throw new Error('Function not implemented.');
      //  },
       items: getEnumItems(property),
       styleType: '1',
     };
     return props;
   },
   traits: () => {
     return [
       {
         type: 'option-icon',
         name: 'icon',
         label: '显示图标',
       },
       {
         type: 'text',
         name: 'title',
         label: '',
       },
       {
         type: 'select',
         name: 'styleType',
         label: '节点样式',
         options: [
           { value: '1', text: '显示节点' },
           { value: '2', text: '不显示节点' },
         ],
       },
       {
         type: 'solt-text',
         name: 'items',
         label: '枚举列表',
       },
       {
         type: 'attribute-title',
         name: 'attributeTitle',
         label: '高级属性',
				 style:{}
       },
       {
         type: 'special-value-setting',
         name: 'specialObj',
         label: '特殊value值设置',
         style: { width: 207, height: 79 },
         src: 'https://storage.jd.com/testsmartcloud/special-value.png',
         description:
           '当控制指令为特殊Value值时，其他值不可使用、点击，特殊Value值一定是通过其他参数触发联动<br />例如：雾量设置-微风/低风/中风/高风/睡眠，睡眠',
       },
     ];
   },
 };
export default grapesJSConfig;

==> smartdev-iot-com-0.0.5.tgz: package/components/enum/IOTPoleSlider/grapesjsConfig.tsx <==
import React from 'react';
import { ComponentsType, iProperty, TagType } from '../../base/type';
import IOTPoleSlider from './IOTPoleSlider';
import { IOTPoleSliderProps } from './interface';
import iGrapesJSConfig from '../../type';
import { iIOTPoleSliderJSON } from '.';
import { mergeParameters } from '../../base/utils';
import { getEnumItems } from '../IOTCordEntryEnum/grapesjsConfig';

 const grapesJSConfig: iGrapesJSConfig<iIOTPoleSliderJSON, IOTPoleSliderProps> = {
   type: [ComponentsType.EnumType],
   id: 'IOTPoleSlider',
   tag: TagType.IOTPoleSlider,
   access: 'rw',
   render: (jsonData, ...args) => {
     const props = mergeParameters(jsonData, ...args);
     return <IOTPoleSlider {...props}></IOTPoleSlider>;
   },
   buildData: (mock: boolean = false, property?: iProperty) => {
     if (property === undefined) return;
     //区分类
     const props: iIOTPoleSliderJSON = {
       title: property['display-name'],
       icon: { value: 'insideicon-cu-1', show: true },
       streamId: property.streamName,
       type: property?.valuedef?.type,
       disabled: false,
       curValue:'',
      //  handler: function (val: any): void {
      //    throw new Error('Function not implemented.');
      //  },
       items: getEnumItems(property),
       styleType: '1',
     };
     return props;
   },
   traits: () => {
     return [
       {
         type: 'option-icon',
         name: 'icon',
         label: '显示图标',
       },
       {
         type: 'text',
         name: 'title',
         label: '',
       },
       {
         type: 'select',
         name: 'styleType',
         label: '节点样式',
         options: [
           { value: '1', text: '显示节点' },
           { value: '2', text: '不显示节点' },
         ],
       },
       {
         type: 'solt-text',
         name: 'items',
         label: '枚举列表',
       },
       {
         type: 'attribute-title',
         name: 'attributeTitle',
         label: '高级属性',
				 style:{}
       },
       {
         type: 'special-value-setting',
         name: 'specialObj',
         label: '特殊value值设置',
         style: { width: 207, height: 79 },
         src: 'https://smartoss.tsy.spic.com.cn/smart-lowcode/static/img/special-value.png',
         description:
           '当控制指令为特殊Value值时，其他值不可使用、点击，特殊Value值一定是通过其他参数触发联动<br />例如：雾量设置-微风/低风/中风/高风/睡眠，睡眠',
       },
     ];
   },
 };
export default grapesJSConfig;
